=== modified file 'bzrlib/tests/__init__.py'
--- bzrlib/tests/__init__.py	2006-01-10 04:08:39 +0000
+++ bzrlib/tests/__init__.py	2006-01-10 05:45:16 +0000
@@ -28,6 +28,7 @@
 import os
 import re
 import shutil
+import stat
 import sys
 import tempfile
 import unittest
@@ -290,6 +291,18 @@
             raise AssertionError("value(s) %r not present in container %r" % 
                                  (missing, superlist))
 
+    def assertMode(self, transport, path, mode):
+        """Fail if a path does not have mode mode.
+        
+        If modes are not supported on this platform, the test is skipped.
+        """
+        if sys.platform == 'win32':
+            return
+        path_stat = transport.stat(path)
+        actual_mode = stat.S_IMODE(path_stat.st_mode)
+        self.assertEqual(mode, actual_mode,
+            'mode of %r incorrect (%o != %o)' % (path, mode, actual_mode))
+
     def _startLogFile(self):
         """Send bzr and test log messages to a temporary file.
 

=== modified file 'bzrlib/tests/test_permissions.py'
--- bzrlib/tests/test_permissions.py	2006-01-03 02:07:06 +0000
+++ bzrlib/tests/test_permissions.py	2006-01-10 05:45:16 +0000
@@ -37,7 +37,7 @@
 from bzrlib.branch import Branch
 from bzrlib.tests import TestCaseInTempDir, TestSkipped
 from bzrlib.tests.test_sftp_transport import TestCaseWithSFTPServer
-from bzrlib.tests.test_transport import check_mode
+from bzrlib.transport import get_transport
 
 
 def chmod_r(base, file_mode, dir_mode):
@@ -63,15 +63,16 @@
     :param include_base: If false, only check the subdirectories
     """
     assert os.path.isdir(base)
+    t = get_transport(".")
     if include_base:
-        check_mode(test, base, dir_mode)
+        test.assertMode(t, base, dir_mode)
     for root, dirs, files in os.walk(base):
         for d in dirs:
             p = os.path.join(root, d)
-            check_mode(test, p, dir_mode)
+            test.assertMode(t, p, dir_mode)
         for f in files:
             p = os.path.join(root, f)
-            check_mode(test, p, file_mode)
+            test.assertMode(t, p, file_mode)
 
 
 def assertEqualMode(test, mode, mode_test):
@@ -303,17 +304,17 @@
             t = SFTPTransport(self._sftp_url)
             # Direct access should be masked by umask
             t._sftp_open_exclusive('a', mode=0666).write('foo\n')
-            check_mode(self, 'a', 0666 &~umask)
+            self.assertMode(t, 'a', 0666 &~umask)
 
             # but Transport overrides umask
             t.put('b', 'txt', mode=0666)
-            check_mode(self, 'b', 0666)
+            self.assertMode(t, 'b', 0666)
 
             t._sftp.mkdir('c', mode=0777)
-            check_mode(self, 'c', 0777 &~umask)
+            self.assertMode(t, 'c', 0777 &~umask)
 
             t.mkdir('d', mode=0777)
-            check_mode(self, 'd', 0777)
+            self.assertMode(t, 'd', 0777)
         finally:
             os.umask(original_umask)
 

=== modified file 'bzrlib/tests/test_transport.py'
--- bzrlib/tests/test_transport.py	2006-01-10 05:25:43 +0000
+++ bzrlib/tests/test_transport.py	2006-01-10 05:45:16 +0000
@@ -31,20 +31,6 @@
                               )
 
 
-if sys.platform != 'win32':
-    def check_mode(test, path, mode):
-        """Check that a particular path has the correct mode."""
-        actual_mode = stat.S_IMODE(os.stat(path).st_mode)
-        test.assertEqual(mode, actual_mode,
-            'mode of %r incorrect (%o != %o)' % (path, mode, actual_mode))
-else:
-    def check_mode(test, path, mode):
-        """On win32 chmod doesn't have any effect, 
-        so don't actually check anything
-        """
-        return
-
-
 class TestTransport(TestCase):
     """Test the non transport-concrete class functionality."""
 

=== modified file 'bzrlib/tests/test_transport_implementations.py'
--- bzrlib/tests/test_transport_implementations.py	2006-01-10 05:25:43 +0000
+++ bzrlib/tests/test_transport_implementations.py	2006-01-10 05:45:16 +0000
@@ -76,16 +76,6 @@
         """Check that transport.get(relpath).read() == content."""
         self.assertEqual(content, transport.get(relpath).read())
 
-    def check_mode(self, transport, path, mode):
-        """Check that a particular path has mode mode."""
-        if sys.platform == 'win32':
-            #win32 has no chmod
-            return
-        path_stat = transport.stat(path)
-        actual_mode = stat.S_IMODE(path_stat.st_mode)
-        self.assertEqual(mode, actual_mode,
-            'mode of %r incorrect (%o != %o)' % (path, mode, actual_mode))
-
     def get_transport(self):
         """Return a connected transport to the local directory."""
         t = bzrlib.transport.get_transport(self._server.get_url())
@@ -188,16 +178,16 @@
         if t.is_readonly():
             return
         t.put('mode644', StringIO('test text\n'), mode=0644)
-        self.check_mode(t, 'mode644', 0644)
+        self.assertMode(t, 'mode644', 0644)
         t.put('mode666', StringIO('test text\n'), mode=0666)
-        self.check_mode(t, 'mode666', 0666)
+        self.assertMode(t, 'mode666', 0666)
         t.put('mode600', StringIO('test text\n'), mode=0600)
-        self.check_mode(t, 'mode600', 0600)
+        self.assertMode(t, 'mode600', 0600)
         # Yes, you can put a file such that it becomes readonly
         t.put('mode400', StringIO('test text\n'), mode=0400)
-        self.check_mode(t, 'mode400', 0400)
+        self.assertMode(t, 'mode400', 0400)
         t.put_multi([('mmode644', StringIO('text\n'))], mode=0644)
-        self.check_mode(t, 'mmode644', 0644)
+        self.assertMode(t, 'mmode644', 0644)
         
     def test_mkdir(self):
         t = self.get_transport()
@@ -253,16 +243,16 @@
             return
         # Test mkdir with a mode
         t.mkdir('dmode755', mode=0755)
-        self.check_mode(t, 'dmode755', 0755)
+        self.assertMode(t, 'dmode755', 0755)
         t.mkdir('dmode555', mode=0555)
-        self.check_mode(t, 'dmode555', 0555)
+        self.assertMode(t, 'dmode555', 0555)
         t.mkdir('dmode777', mode=0777)
-        self.check_mode(t, 'dmode777', 0777)
+        self.assertMode(t, 'dmode777', 0777)
         t.mkdir('dmode700', mode=0700)
-        self.check_mode(t, 'dmode700', 0700)
+        self.assertMode(t, 'dmode700', 0700)
         # TODO: jam 20051215 test mkdir_multi with a mode
         t.mkdir_multi(['mdmode755'], mode=0755)
-        self.check_mode(t, 'mdmode755', 0755)
+        self.assertMode(t, 'mdmode755', 0755)
 
     def test_copy_to(self):
         from bzrlib.transport.memory import MemoryTransport
@@ -304,7 +294,7 @@
             temp_transport = MemoryTransport("memory:/")
             t.copy_to(files, temp_transport, mode=mode)
             for f in files:
-                self.check_mode(temp_transport, f, mode)
+                self.assertMode(temp_transport, f, mode)
 
     def test_append(self):
         t = self.get_transport()

